********************************************************************************
*               Generate file with statutory retirement age                    *
* Thomas Leoni file 23/11/2017, adapted by BBG 27/11/2017 into main datafile   *
********************************************************************************

*_________________________________________________________________________________________________________________________________________________
* 
* FIRST STEP: extract information from SHARE jobepisodes file
*_________________________________________________________________________________________________________________________________________________

/* HOW THE SHARE JOBEPISODES FILE CALCULATED THIS:
	 Statutory retirement age in SHARE jobepisodes file has been taken from MISSOC (see Antonova et al., SHARE working paper series 18-2014)

	 Statutory retirement age in a country is the age at which a person is expected or required to cease working and at which she 
	 may be entitled to receive pension benefits. In many countries, statutory retirement age is different for males and females, for 
	 which information on the gender of each respondent is retrieved from the SHARE dataset and utilized to estimate individual retirement ages.
	 The base assumption made when constructing this variable is that statutory retirement age in all countries is mainly age-dependent. 
	 However, in some countries other conditions may apply (e.g., qualifying minimum periods of contributions, degree of disability, years of 
	 military service, etc.). The statutory retirement age provided in the present dataset does not account for such secondary requirements. 

	 An exception is the Czech Republic, where the statutory retirement age for females depends on the number of children raised. To account  
	 for such requirement, information on the number of natural and adopted children alive at the time of interview is included for the calculation 
	 of the retirement age of female respondents from the Czech Republic.

	 Due to a pension reform, statutory retirement age increased in Greece to 65 for all those men and women who started working on or after 1993. 
	 The data allow us to take this into account; the adjusted retirement age also applies to all individuals who report not having worked before 1993.  
	 
	 Thomas Leoni notes: : I did not find information on Israel, and I also did not include those countries which we already decided to discard (LUX, HR, PT, HU).
*/


// Get the relevant subset of data for merging in
use "${sharedir}\SHARE allwaves\Job Episodes Panel\sharewX_${shareversno}_gv_job_episodes_panel.dta", clear
keep if ret_age!=.      // restrict to information applicable to interview years 2004 and after
keep if year>2003
keep country ret_age gender year 
drop if inlist(country,19, 28)  		// drop Greece, Czech Republic
bysort country year gender: keep if _n==1
save "${sharedir}\SHARE_BB_${versno}_ret_age.dta", replace


/* CHECKS FOR CHANGES OF TIME:
	bysort country gender: table ret_age year
	(1)	Countries with no change/differences for the period 2004 to 2008:
    	11 Austria (M65/F60), 12 Germany (M65/F65), 13 Sweden (M65/F65), 14 Netherlands (M65/F65), 15 Spain (M65/F65), 
		16 Italy (M65/F60), 17 France (M60/F60), 18 Denmark (M65/F65), 29 Poland (M65/F60), 30 Ireland (M66/F66)
	
	(2)	Countries with (some) clear-cut changes in legislation:
		20 Switzerland (increase for F from 63 in 2004 to 64 in 2005)
		23 Belgium (increase for F from 63 in 2004 to 64 in 2005)
	
	(3)	Countries with more complex/shifting rules:
		19 Greece (F65 for women who started working on or after 1993, but 1960 for the others)
		28 Czech Republic (increase from 61.33 in 2004 to 61.5 in 2005 to 61.67 in 2007 and 61.83 in 2008; rule depending on children for women, see above)
*/



*_________________________________________________________________________________________________________________________________________________
* 
* SECOND STEP: merge in retirement age information to main datafile
*_________________________________________________________________________________________________________________________________________________

use "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace

/* Retain only the following countries: 51 USA, 61 England plus 
11 Austria, 12 Germany, 13 Sweden, 14 Netherlands (4 waves), 15 Spain, 16 Italy, 17 France, 18 Denmark, 19 Greece (3 waves), 20 Switzerland, 
23 Belgium, 25 Israel (4 waves), 28 Czech Republic (4 waves),29 Poland (3 waves),34 Slovenia (3 waves),35 Estonia (3 waves). */
keep if inlist(country, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 23, 25, 28, 29, 34, 35, 51, 61)

// Merging at individual level into job episodes panel
// (only for Greece because ret_age is calculated on the basis of individual contributory history)
* Other things necessary to match
recode rmale (0=2 "2_female")(1=1 "1_male"), gen(gender)
rename year yeartmp
rename riwy year
* Main merging
merge 1:1 mergeid year using "${sharedir}\SHARE allwaves\Job Episodes Panel\sharewX_${shareversno}_gv_job_episodes_panel.dta" ///
	, keepusing(ret_age) generate(merge_retage) keep(match master)
* Only use this for Greece
replace ret_age=. if country!=19
	
// Merging at country level for all other countries
merge m:1 country year gender using "${sharedir}\SHARE_BB_${versno}_ret_age.dta", replace update
drop if _merge==2
table country_waveN, c(count ret_age count rworknew)




*_________________________________________________________________________________________________________________________________________________
* 
* THIRD STEP: extend ret_age to 2008-2015, plus additional info for some countries
*_________________________________________________________________________________________________________________________________________________

/* 	(1) Countries with no change since 2008
    	11 Austria (M65/F60), 13 Sweden (M65/F65), 18 Denmark (M65/F65), 20 Switzerland (M65/F64), 30 Ireland (M66/F66)
*/
replace ret_age=65 if (year>2008 & year<2016) & (country==11 | country==13 | country==18 | country==20) & gender==1  // men until 65 in multiple countries
replace ret_age=65 if (year>2008 & year<2016) & (country==13 | country==18) & gender==2                              // women until 65
replace ret_age=60 if (year>2008 & year<2016) & country==11 & gender==2   											 // women in Austria
replace ret_age=64 if (year>2008 & year<2016) & country==20 & gender==2   											 // women in Switzerland
replace ret_age=66 if (year>2008 & year<2016) & country==30    														 // Ireland



/*	(2)	Countries with change(s) with respect to 2008:
    	12 Germany: starting 2012, 1 month per year increase for both men and women
		14 Netherlands: Gradual increase to 66 from 2015 to 2018, three months per year
		15 Spain: No change for those with 36 years and 3 months of contributions; gradual increase by 1 month per year starting in 2013 until 2018 for the others
		16 Italy: Change to M66/F62 in 2012, M66.25/F66.25 in 2013 and M66.25/F63.75 in 2015
		17 France: In 2011 (July) increase by 4 month for each birthyear starting with cohort >1 July 1951 and up to cohort 1956 (ret age 62)
		23 Belgium: Change from 64 to 65 for women in 2009
		28 Czech Republic (increase from 61.33 in 2004 to 61.5 in 2005 to 61.67 in 2007 and 61.83 in 2008; rule depending on children for women, see above)
		29 Poland: As of 1 January 2013 the retirement age will gradually increase by one month per three months for every age cohort, until it reaches 67 for both men (start with birthyear 1949) and women (1953)
		34 Slovenia: see excel file
		35 Estonia: see excel file
		50 United States: Gradual increase from 65 to 67, depending on birthyear (starting with birthyear 1938, phased in between 2000 and 2027), see https://www.ssa.gov/oact/progdata/nra.html
		61 England: M65/F60 until 2010, then gradual increase for women to reach 65 on a par with men in December 2018
*/
 
* 12-Germany
replace ret_age=65 						if (year>2008 & year<2012) & country==12 
replace ret_age=65 + (year-2011)*1/12 	if country==12 & year>2011 
 
* 14-Netherlands 
replace ret_age=65 						if (year>2008 & year<2015) & country==14 
replace ret_age=65.25 					if year==2015 & country==13 

* 15-Spain
replace ret_age=65 						if (year>2008 & year<2013) & country==15 
replace ret_age=65 + (year-2012)*1/12 	if country==15 & year>2012 
 
 * 16-Italy
replace ret_age=65  					if country==16 & year==2011 & gender==1
replace ret_age=66.3 					if country==16 & year==2013 & gender==1
replace ret_age=66.3 					if country==16 & year==2015 & gender==1
replace ret_age=60   					if country==16 & year==2011 & gender==2
replace ret_age=62.3 					if country==16 & year==2013 & gender==2
replace ret_age=63.8 					if country==16 & year==2015 & gender==2

* 17-France
replace ret_age=60.3 					if country==17 & year==2011
replace ret_age=61  					if country==17 & year==2013
replace ret_age=61.3 					if country==17 & year==2015

* 19-Greece
gen ret_group=1 if country==19
sort mergeid year
bys mergeid: replace ret_group=2 		if ret_age[_n-1]==60 & country==19 & year==2015   	// identify those with lower pension age in previous wave
replace ret_age=62 						if country==19 & ret_group==2           			// adapt to 62 those with lower pension age
replace ret_age=65 						if country==19 & year==2015 & ret_age==.   			// set all others to 65 (conservative approach, not 67 because unclear to whom this applies)
drop ret_group
* Additional syntax from Thomas 12/12/2017- fill in missings from Waves 1 & 2, respondents who did not participate in SHARELIFE; use "conservative" ret_age (60 for women, 65 for men) 
replace ret_age = 65					if country==19 & (year==2004 | year==2005 | year==2007) & ret_age==. & gender==1
replace ret_age = 60 					if country==19 & (year==2004 | year==2005 | year==2007) & ret_age==. & gender==2

 
* 23-Belgium
replace ret_age=65 if (year>2008 & year<2016) & country==23

* 28-Czech Republic
/* See MISSOC (1/5/2004): Women: depends upon the number of children raised: no children#59 years and 4 months, 1 child#58 years and 4 months, 
2 children#57 years and 4 months, 3 or 4 children#56 years and 4 months, 5 or more children#55 years and 4 months.
=> i.e. one year less per child for first and second child, one additional year less for third/fourth child, one year less for fifth and successive children
*/
* Women initial age
replace ret_age = 59.33 				if year==2004 & country ==28 & gender==2
replace ret_age = 59.67 				if year==2005 & country ==28 & gender==2
replace ret_age = 59.67 				if year==2006 & country ==28 & gender==2
replace ret_age = 60 					if year==2007 & country ==28 & gender==2
replace ret_age = 60.33 				if year==2008 & country ==28 & gender==2
replace ret_age = 60.7 					if year==2011 & country ==28 & gender==2
replace ret_age = 61.33 				if year==2013 & country ==28 & gender==2
replace ret_age = 62 					if year==2015 & country ==28 & gender==2
* Women adjustments for number of children
replace ret_age = ret_age-(1*hchild) 	if hchild>0 & hchild<2 			& country ==28 & gender==2
replace ret_age = ret_age-3 			if (hchild==3 | hchild==4) 		& country ==28 & gender==2
replace ret_age = ret_age-4 			if hchild>4 & !missing(hchild) 	& country ==28 & gender==2
* Men
replace ret_age = 61.5 					if year==2006 & country ==28 & gender==1
replace ret_age = 61.67 				if year==2007 & country ==28 & gender==1
replace ret_age = 62.3 					if year==2011 & country ==28 & gender==1
replace ret_age = 62.5 					if year==2013 & country ==28 & gender==1
replace ret_age = 62.8 					if year==2015 & country ==28 & gender==1

* 29-Poland
replace ret_age = 65.58 				if country==29 & year==2015 & gender==1
replace ret_age = 60.58 				if country==29 & year==2015 & gender==2
* Added 12/12/2017 to fill in missings
replace ret_age = 65 					if country==29 & (year==2011 | year==2012) & gender==1 
replace ret_age = 60 					if country==29 & (year==2011 | year==2012) & gender==2

* 34-Slovenia
replace ret_age=63 						if country==34 & year==2011 & gender==1 
replace ret_age=65 						if country==34 & year==2013 & gender==1
replace ret_age=65 						if country==34 & year==2015 & gender==1

replace ret_age=61 						if country==34 & year==2011 & gender==2 
replace ret_age=65 						if country==34 & year==2013 & gender==2
replace ret_age=65 						if country==34 & year==2015 & gender==2

* 35-Estonia
replace ret_age=63 						if country==35 & year>=2008 & gender==1 
replace ret_age=61 						if country==35 & (year==2010 | year==2011) & gender==2 
replace ret_age=62 						if country==35 & year==2013 & gender==2
replace ret_age=62.5 					if country==35 & year==2015 & gender==2

* 50-United States
replace ret_age=65 								if country==51                               // USA: for normal retirement age in USA see https://www.ssa.gov/oact/progdata/nra.html
replace ret_age=65 + 0.1666 * (rabyear - 1937) 	if country==51 & rabyear>1937 & rabyear<1943
replace ret_age=66								if country==51 & rabyear>=1943 & rabyear<1955
replace ret_age=66 + 0.1666 * (rabyear - 1954) 	if country==51 & rabyear>=1955
replace ret_age=67 								if ret_age>66.99 & country==51

* 61-England - see BBG spreadsheet
replace ret_age=65 						if country==61 & gender==1
replace ret_age=60 						if country==61 & gender==2 				
replace ret_age=60.5 					if country==61 & gender==2 & year==2011 & rabyear<=1950
replace ret_age=60.8 					if country==61 & gender==2 & year==2011 & rabyear>=1951
replace ret_age=61 						if country==61 & gender==2 & year==2012 
replace ret_age=61.5 					if country==61 & gender==2 & year==2013 & rabyear<=1951
replace ret_age=61.8 					if country==61 & gender==2 & year==2013 & rabyear>=1952
replace ret_age=62 						if country==61 & gender==2 & year==2014 	
replace ret_age=62.5					if country==61 & gender==2 & year==2015 & rabyear<=1952
replace ret_age=62.7					if country==61 & gender==2 & year==2015 & rabyear>=1953



*_________________________________________________________________________________________________________________________________________________
* 
* FINAL CHECKS & TIDYING
*_________________________________________________________________________________________________________________________________________________

/* Test consistency of retirement age classification
bys country: table year ret_age if gender==1  
bys country: table year ret_age if gender==2
bys year: table country ret_age if gender==1
bys year: table country ret_age if gender==2
bys country: tab ret_age, m
*/

//  Tidying up
drop _merge merge_retage gender
* Reversing renaming just above
rename year			riwy 
rename yeartmp		year 
label var ret_age		"Statutory retirement age AT PRESENT TIME (ignoring planned increases before will reach it)"
* Keep and save retirement age information
*keep survey mergeid wave country rmale ret_age		// Now just keep this as the full dataset, rather than just retirement age ino
save "${hrsdir}\HRS-SHARE-ELSA_BBG_${versno}.dta", replace

  
  
 
